@@ -3,10 +3,9 @@
 import requests
 
 from guniflask.context import configuration, bean
+from guniflask.config import settings
 from guniflask.oauth2_config import enable_resource_server, ResourceServerConfigurerAdapter
 from guniflask.oauth2 import TokenStore, JwtTokenStore, JwtAccessTokenConverter
-from guniflask.config import settings
-from guniflask.security_config import enable_web_security, WebSecurityConfigurer, HttpSecurity
 
 
 @configuration
@@ -33,18 +32,8 @@ class MicroserviceResourceConfiguration(ResourceServerConfigurerAdapter):
 
     def _get_key_from_authorization_server(self):
         server: str = settings.get_by_prefix('guniflask.authorization_server')
-        if not (server.startswith('http://') or server.startswith('https://')):
+        if '://' not in server:
             server = 'http://' + server
         resp = requests.get('{}/oauth/token_key'.format(server.rstrip('/')))
         assert resp.status_code == 200, 'Failed to get token key from authorization server'
         return resp.json()
-
-
-@configuration
-@enable_web_security
-class MicroserviceWebSecurityConfiguration(WebSecurityConfigurer):
-
-    def configure_http(self, http: HttpSecurity):
-        cors = settings.get_by_prefix('guniflask.cors')
-        if cors:
-            http.cors(cors)
